package
Version:
v1.34.30
Opens a new window with list of versions in this module.
Published: Aug 3, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package adapter runs negotiated external PawnKit tools.
type Result struct {
SchemaVersion int `json:"schemaVersion"`
Status string `json:"status"`
Message string `json:"message,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.