package
Version:
v1.34.18
Opens a new window with list of versions in this module.
Published: Aug 3, 2026
License: MIT
Opens a new window with license information.
Imports: 16
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package audit inspects resolved project supply-chain metadata.
type Finding struct {
ID string `json:"id"`
Severity string `json:"severity"`
Certainty string `json:"certainty"`
Message string `json:"message"`
Package string `json:"package,omitempty"`
}
type Metadata struct {
Offline bool `json:"offline"`
Source string `json:"source"`
Timestamp string `json:"timestamp,omitempty"`
}
type Report struct {
SchemaVersion int `json:"schemaVersion"`
Metadata Metadata `json:"metadata"`
Disclaimer string `json:"disclaimer"`
Findings []Finding `json:"findings"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.