package
Version:
v1.34.38
Opens a new window with list of versions in this module.
Published: Aug 3, 2026
License: MIT
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package doctor aggregates safe project health checks.
type Finding struct {
ID string `json:"id"`
Severity string `json:"severity"`
Certainty Certainty `json:"certainty"`
Source string `json:"source"`
Path string `json:"path,omitempty"`
Message string `json:"message"`
Remediation *Remediation `json:"remediation,omitempty"`
}
type Remediation struct {
Class FixClass `json:"class"`
Command string `json:"command,omitempty"`
Message string `json:"message"`
}
type Report struct {
SchemaVersion int `json:"schemaVersion"`
Findings []Finding `json:"findings"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.