Discover Packages
github.com/pawnkit/pawnkit-cli
pkg
workflow
package
Version:
v1.34.30
Opens a new window with list of versions in this module.
Published: Aug 3, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Package workflow runs deterministic command task graphs.
type Finding struct {
RuleID string `json:"ruleId"`
Severity string `json:"severity"`
Message string `json:"message"`
Path string `json:"path"`
Line int `json:"line"`
Column int `json:"column"`
}
type Result struct {
Name string `json:"name"`
Status string `json:"status"`
Tool string `json:"tool,omitempty"`
Message string `json:"message,omitempty"`
Findings []Finding `json:"findings,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.